import React from 'react';
import PropTypes from 'prop-types';

class TextFilter extends React.Component {
    render() {
        // Options are hardcoded for now but can be passed via props from parent
        const selectOptions = [
            {
                value: 'equals',
                caption: 'Equals',
            },
            {
                value: 'notEqual',
                caption: 'Not Equals',
            },
            {
                value: 'contains',
                caption: 'Contains',
            },
            {
                value: 'notContains',
                caption: 'Not Contains',
            },
            {
                value: 'startsWith',
                caption: 'Starts With',
            },
            {
                value: 'endsWith',
                caption: 'Ends With',
            },
        ];

        const {
            field,
            width,
            textBoxes,
            nameStyle,
            selectStyles,
            inputStyles,
            placeholder,
            selectedFilterOption,
        } = this.props;
        return (
            <div style={ {
                width: width,
                ...nameStyle,
            } }>
                { /* eslint-disable-next-line jsx-a11y/no-onchange */ }
                <select
                    style={ selectStyles }
                    className="ag-filter-select"
                    onChange={ this.handleTextChange }
                    value={ selectedFilterOption[field] }
                    ref={ (ref) => this.select = ref }>
                    {
                        selectOptions.map((selectOption) => (
                            <option
                                key={ `${field}__${selectOption.value}` }
                                value={ selectOption.value }>
                                { selectOption.caption }
                            </option>
                        ))
                    }
                </select>
                <input
                    style={ { ...inputStyles } }
                    onChange={ this.handleTextChange }
                    ref={ (ref) => { this.text = ref ; } }
                    placeholder={ placeholder }
                    value={ textBoxes[field] || '' } />
            </div>
        );
    }

    /** Pass on filter text value */
    handleTextChange = () => {
        const {
            field,
            onTextChanged,
        } = this.props;
        const textBoxes = {
            [field]: this.text.value,
        };

        if (onTextChanged) {
            onTextChanged(field, textBoxes, this.select.value);
        }
    };
};

TextFilter.propTypes = {
    /** Column width */
    width: PropTypes.string,

    /** Column identifier (field name) */
    field: PropTypes.string,

    /** Placeholder string for number input field. */
    placeholder: PropTypes.string,

    /** Filter text values for each field/column */
    textBoxes: PropTypes.object,

    /** Selected filter option, e.g. contains, equals etc. */
    selectedFilterOption: PropTypes.object,

    /** Passes on changed value */
    onTextChanged: PropTypes.func,

    /** Name filter style */
    nameStyle: PropTypes.object,

    /** Filter for select element */
    selectStyles: PropTypes.object,

    /** Style for input field */
    inputStyles: PropTypes.object,
};

export default TextFilter;
